[![Build Status](https://travis-ci.org/leonardt/hwtypes.svg?branch=master)](https://travis-ci.org/leonardt/hwtypes)


# Install
## Debian
```
apt install libgmp-dev libmpfr-dev libmpc-dev
pip install hwtypes
```
## OSX
```
brew install gmp mpfr libmpc
pip install hwtypes
```
